# If we assume that the year-to-year number of fatalities is distributed as a Poisson with uncertain rate lambda,
# we can use the previous year's data to get an estimate on the distribution of lambda and use the resulting
# distribution as a prior for the new year's data.

# If we take a uniform prior for lambda, then we need to calculate P(lambda|X)=P(X|lambda)/integral(P(X|lambda)).
# The observed count X is a binomial random variable with uncertain p. However, the bounds on p are read from the
# search data from the previous year. [NOTE: Once the lambda distribution is estimated, the old bounds on p are
# thrown out and the new year's bounds are used for determining the posterior for the second year.

# Calculate a distribution of lambda given a prior for lambda (assume it's uniform if none is given)
Lx<-seq(.1,(X+1)/minp+10*sqrt((X+1)/minp), by=.1) # x-values associated with priorL
priorL<-1/length(Lx)+numeric(length(Lx)) # what we assume lambda to be before we do any searches (probabilities that match with Lx)
M<-0:round(max(Lx)+10*sqrt(max(Lx)))
pXgMpM<-array(dim=c(length(priorL),length(M)))
mu<-pmean; sig2<-((maxp-minp)/4)^2
pBa<-mu^2/sig2*(1-mu)-mu; pBb<-pBa*(1/mu-1) # these are the two shape parameters for the beta distribution underlying the beta-binomial for X | M
for (i in 1:length(M)){
   pXgMpM[,i]<-dbetabinom.ab(X,size=M[i],shape1=pBa,shape2=pBb)*dpois(M[i],Lx)
}
pXgL<-pXgMpM%*%(1+numeric(length(M)))
pLgX<-pXgL/sum(pXgL) # this is the posterior of lambda after the first year's search...it looks just like a gamma distribution, which would make a prior M for the next year a negative binomial.
# Alternatively, we could just calculate the M's arising from this empirical list of probabilities.
pMgLpL<-array(dim=c(length(M),length(priorL)))
for (i in 1:length(M)){
   pMgLpL[i,]<-sum(dpois(M[i],Lx)*pLgX)
}
pM<-pMgLpL%*%(1+numeric(length(priorL)))/length(priorL)
pM<-pM/sum(pM)
pM<-pM[cumsum(pM)<=0.9995]
pM<-pM/sum(pM)
M<-M[1:length(pM)]
EM<-sum(M*pM)
q95<-min(which(cumsum(pM)>.95))-1
sig<-sqrt(sum(M^2*pM)-EM^2)