# minformed prior: a prior informed by multiple years of data
# the myr array (nyr x 5) is expected to have been defined in R
X<-myr[,1]; nX<-length(X) # the counts for year 1, ..., nX
g<-myr[,2]; # average overall detection probabilities
minp<-myr[,3]; maxp<-myr[,4]; # min and max of 95% CI of min and max p
a<-myr[,5] # relative arrival rate from year to year

# STEP 1: derive beta distribution parameters for detection probabilities
# Assume that the standard deviation of the detection probability for a given year is 0.25 * (width of CI), i.e. 95% bounds are +- 2 sd's from the mean
mu<-g; sig2<-((maxp-minp)/4)^2
pBa<-mu^2/sig2*(1-mu)-mu; pBb<-pBa*(1/mu-1) # these are the two shape parameters for the beta distribution underlying the beta-binomial for X | M
# Although unlikely, a derived beta distribution may be bimodal--unrealistic.
# Problem: estimate of the variance is too big
# Solution: gradually reduce the variance until model is unimodal
for (i in 1:nX){
  while (pBa[i] < 1 & pBb[i] <1){ # if the beta parameters are equal, the distribution is symmetric, flat but with spikes on both ends. Setting both parameters equal to 1 clips the spikes.
    if (pBa[i]==pBb[i]){
      pBa[i]<-1
      pBb[i]<-1
    } else {
      sig2<-sig2*.99
      pBa[i]<-mu^2/sig2*(1-mu)-mu; pBb[i]<-pBa[i]*(1/mu-1) # these are the two shape parameters for the beta distribution underlying the beta-binomial for X | M
    }
  }
}
Lmax<-max(max((X+.5)/g)+5*sqrt(max((X+.5)/g)),20); Lincr<-.1; Lmin<-Lincr
mmax<-qpois(.9999,Lmax)
L<-seq(Lmin,Lmax,by=Lincr) # possible values for L (continuum, but approximated)
M<-0:mmax #possible values for M
nX<-length(X); nM<-length(M); nL<-length(L)
#pXgML<-to.tensor(dbetabinom.ab(X,size=rep(sort(rep(M,nX)),nL),pBa,pBb)*dpois(rep(sort(rep(M,nX)),nL),sort(rep(L,nM*nX))*a),c(x=nX,m=nM,l=nL))
lamvec<-sort(rep(L,nM*nX))*a
vm.ratio<-5 # set by hand
pXgML<-to.tensor(dbetabinom.ab(X,size=rep(sort(rep(M,nX)),nL),pBa,pBb)*dnbinom(rep(sort(rep(M,nX)),nL),size=lamvec/(vm.ratio-1),prob=1/vm.ratio),c(x=nX,m=nM,l=nL))
pXgL<-margin.tensor(pXgML,i='m')
pL<-exp(margin.tensor(log(pXgL),i='x'))
pL<-pL/sum(pL)
pMgL<-to.tensor(dpois(rep(M,nL),sort(rep(L,nM))),c(m=nM,l=nL))
pM<-einstein.tensor(pMgL,pL)
pM<-pM[1:min(which(cumsum(pM)>.9995))]
pM<-as.vector(pM/sum(pM))
M<-M[1:length(pM)]
q95<-min(which(cumsum(pM)>.95))+1
