##### Input data myr and crlev are read in from Excel before the following script is run.
### The function calculates an overall average g along with estimated variance.
### Posterior is betabinomial on g and is calculated based on a uniform prior.
X<-myr[,1]; nyr<-length(X)
mu<-myr[,2]; minp<-myr[,3]; maxp<-myr[,4]; a<-myr[,5]/sum(myr[,5])
# p is assumed to be distributed as a beta RV with mean = pmean and variance = ((maxp-minp)/4)^2.
# This determines beta parameters as follows:
sig2<-((maxp-minp)/4)^2 # estimated means and uncertainties for g
Eg<-sum(mu*a) # average, expected G is the weighted average of the observed g's
lambda<-max(sum(X), 0.5)/Eg
Vg<-sum(sig2*a^2)+(sum(a*(mu^2+sig2))-Eg^2)/lambda
pBa<-Eg^2/Vg*(1-Eg)-Eg; pBb<-pBa*(1/Eg-1) # these are the two shape parameters for the beta distribution underlying the beta-binomial for X | M
gmin<-qbeta(.025,shape1=pBa,shape2=pBb); gmax<-qbeta(.975,shape1=pBa,shape2=pBb)
#require(VGAM)
### M needs to be calculated up to a reasonable maximum, but the final distribution is clipped at P(M > m) < 0.0001
mm<-(sum(X)+1)/min(minp)#;
mmax<-floor(mm+10*sqrt(mm))+1
M<-0:mmax; aleph<-0.01
pM<-rep(1/length(M),length(M)) # M on a myr basis

# STEP 3. Estimate the probability of X given M for M in 0:mmax
pXgM<-dbetabinom.ab(sum(X),size=M,shape1=pBa,shape2=pBb) # the probabilities of X for M = 0:mmax

# STEP 4. Calculate the posterior for M
pMgX<-numeric(length(M))
deno<-sum(pXgM[1:length(M)]*pM)
pMgX<-pXgM*pM/deno
cs<-cumsum(pMgX)
pMem<-pMgX[1:min(which(cs>.999))]
pMem<-pMem/sum(pMem)
py<-c(1,1-cumsum(pMem[-length(pMem)]))
m<-1:length(py)-1
plot(m,py,xlab='m',ylab=paste("Prob( M \u2265 m | X = ", sum(X) ,")"))

#plot(m,1-cumsum(pMem),xlab='m',ylab=paste("Prob( M \u2265 m | X = ", X ,")"))
bringToTop()
col.use=rep("black", max(m))
cut.off<-min(which(py<=1-crlev))-1
cmax<-cut.off-1
col.use[m[1]:(cut.off)]="red"
if (cut.off > 100) {
   wid<-1
} else if (cut.off < 50){
  wid<-3
} else {
   wid<-2
}
for(i in 1:length(m)){
  lines(x=rep(i-1,2), y= c(0,py[i]), col=col.use[i], lwd=wid)
}
top<-1

text(max(m),top,paste("Overall detection probability: g = ",signif(Eg,4), "\n 95% CI = [ ",signif(gmin,4),", ",signif(gmax,4),"]",sep=""),adj=1,cex=.85)
text(max(m),.9*top,paste("P(M \u2264 ",  m[cut.off],") \u2265 ", crlev*100, "%",sep=''),adj=1,cex=.85)

if (shyr==1){
  title(paste("Posterior Distribution of Total Fatalities over ",dim(myr)[1]," years",sep=""))
} else {
  title(paste("Posterior Distribution of Total Fatalities across ",dim(myr)[1]," classes",sep=""))
}
M<-1:length(pMem)-1
CpMem<-1-cumsum(pMem)